@@ -44,7 +44,6 @@ class FauxDebianPlugin(Plugin, DebianPlugin):
 
 class PolicyTests(unittest.TestCase):
 
-
     def test_independent_only(self):
         p = FauxPolicy()
         p.valid_subclasses = []
@@ -88,17 +87,17 @@ class PackageManagerTests(unittest.TestCase):
         self.pm = PackageManager()
 
     def test_default_all_pkgs(self):
-        self.assertEquals(self.pm.packages, {})
+        self.assertEqual(self.pm.packages, {})
 
     def test_default_all_pkgs_by_name(self):
-        self.assertEquals(self.pm.all_pkgs_by_name('doesntmatter'), [])
+        self.assertEqual(self.pm.all_pkgs_by_name('doesntmatter'), [])
 
     def test_default_all_pkgs_by_name_regex(self):
-        self.assertEquals(
+        self.assertEqual(
             self.pm.all_pkgs_by_name_regex('.*doesntmatter$'), [])
 
     def test_default_pkg_by_name(self):
-        self.assertEquals(self.pm.pkg_by_name('foo'), None)
+        self.assertEqual(self.pm.pkg_by_name('foo'), None)
 
 
 class RpmPackageManagerTests(unittest.TestCase):
@@ -109,13 +108,13 @@ class RpmPackageManagerTests(unittest.TestCase):
         self.pm = RpmPackageManager()
 
     def test_load_all_packages(self):
-        self.assertNotEquals(self.pm.packages, {})
+        self.assertNotEqual(self.pm.packages, {})
 
     def test_pkg_is_formatted(self):
         kpkg = self.pm.pkg_by_name('coreutils')
         self.assertIsInstance(kpkg, dict)
         self.assertIsInstance(kpkg['version'], list)
-        self.assertEquals(kpkg['pkg_manager'], 'rpm')
+        self.assertEqual(kpkg['pkg_manager'], 'rpm')
 
 
 class DpkgPackageManagerTests(unittest.TestCase):
@@ -126,13 +125,13 @@ class DpkgPackageManagerTests(unittest.TestCase):
         self.pm = DpkgPackageManager()
 
     def test_load_all_packages(self):
-        self.assertNotEquals(self.pm.packages, {})
+        self.assertNotEqual(self.pm.packages, {})
 
     def test_pkg_is_formatted(self):
         kpkg = self.pm.pkg_by_name('coreutils')
         self.assertIsInstance(kpkg, dict)
         self.assertIsInstance(kpkg['version'], list)
-        self.assertEquals(kpkg['pkg_manager'], 'dpkg')
+        self.assertEqual(kpkg['pkg_manager'], 'dpkg')
 
 
 class MultiPackageManagerTests(unittest.TestCase):
@@ -142,7 +141,7 @@ class MultiPackageManagerTests(unittest.TestCase):
                                       fallbacks=[DpkgPackageManager])
 
     def test_load_all_packages(self):
-        self.assertNotEquals(self.pm.packages, {})
+        self.assertNotEqual(self.pm.packages, {})
 
     def test_pkg_is_formatted(self):
         kpkg = self.pm.pkg_by_name('coreutils')
@@ -150,9 +149,9 @@ class MultiPackageManagerTests(unittest.TestCase):
         self.assertIsInstance(kpkg['version'], list)
         _local = distro.detect().name
         if _local in ['Ubuntu', 'debian']:
-            self.assertEquals(kpkg['pkg_manager'], 'dpkg')
+            self.assertEqual(kpkg['pkg_manager'], 'dpkg')
         else:
-            self.assertEquals(kpkg['pkg_manager'], 'rpm')
+            self.assertEqual(kpkg['pkg_manager'], 'rpm')
 
 
 if __name__ == "__main__":
